/*
 *  mpqc.c -- console mpq unpacker, based on libmpq
 *  See https://libmpq.org/wiki/SourceCodeExamples
 *  Copyright (c) 2008-2011 Mix <ru-mangos.ru>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#ifdef __MSVCRT__
#include <fcntl.h> /* O_BINARY */
#include <io.h>    /* setmode */
#endif
#include "mpq.h"

int main(int argc, char **argv)
{
  if (argc != 2 && argc != 3)
  {
    fprintf(stderr,
            "Very simple mpq extractor\n"
            "USAGE:\n  mpq <archive.mpq> [<filename>]\n"
            "WARNING: File content is printed to stdout\n"
            "If <filename> is not specified a list of all files is printed\n");
    return 1;
  }

  mpq_archive_s *a;
  unsigned int file_number;
  off_t file_size;
  const char *filename;
  unsigned char *content;

  if (argc == 3)
    filename = argv[2];
  else
    filename = "(listfile)";

  libmpq__init();//comment this out for libmpq svn trunk

  // open archive
  if (libmpq__archive_open(&a, argv[1], -1) != 0)
  {
    fprintf(stderr, "Error opening '%s'.\n", argv[1]);
    return 2;
  }

  // get file_number and size for requested file
  if (libmpq__file_number(a, filename, &file_number) != 0)
  {
    fprintf(stderr, "No %s in '%s'.\n", filename, argv[1]);
    libmpq__archive_close(a);
    return 3;
  }
  libmpq__file_unpacked_size(a, file_number, &file_size);

  // read file content into memory
  content = malloc(file_size);
  if (libmpq__file_read(a, file_number, content, file_size, NULL) != 0)
  {
    fprintf(stderr, "Error reading %s from '%s'.\n", filename, argv[1]);
    libmpq__archive_close(a);
    return 4;
  }

  // and write it to stdout
#ifdef __MSVCRT__
  setmode(STDOUT_FILENO, O_BINARY);
#endif
  write(STDOUT_FILENO, content, file_size);
  free(content);

  libmpq__archive_close(a);

  libmpq__shutdown();//comment this out for libmpq svn trunk

  return 0;
}
